@@ -159,7 +159,7 @@ class OAuthTwitterTest(TestCase):
                                        follow=True)
             self.assertEqual(
                 response.redirect_chain,
-                [('http://testserver/twitter/associate/?associated=1', 302)]
+                [('http://testserver/twitter/associate/', 302)]
             )
             self.assertEqual(response.status_code, 200)
 
@@ -312,8 +312,7 @@ class OAuthTwitterTest(TestCase):
             self.assertEqual(response['Location'],
                              reverse(oauthtwitter.register))
             response = o.callback(request)
-            self.assertEqual(response['Location'],
-                             '/home/?associated=1')
+            self.assertEqual(response['Location'], '/home/')
 
     def test_signin(self):
         response = self.client.get(reverse('twitter_signin'))
