@@ -4,6 +4,7 @@ from urllib2 import HTTPError, URLError
 from urlparse import urlsplit, urlunsplit
 
 from django.conf import settings
+from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.core.urlresolvers import reverse
 from django.utils.functional import update_wrapper
 
@@ -51,6 +52,16 @@ def fail_whale(f):
 def get_user_info(access_token):
     return TwitterApi(access_token).GetUserInfo()
 
+def _host(netloc):
+    return netloc.split(':')[0]
+
+def next_url(request):
+    result = request.REQUEST.get(REDIRECT_FIELD_NAME, None)
+    if result is None or \
+       _host(urlsplit(result).netloc) != _host(request.get_host()):
+        result = login_redirect_url()
+    return result
+
 def login_redirect_url():
     """
     Returns the URL to redirect to, after a login.
