@@ -22,7 +22,7 @@ from django_oauth_twitter.models import (TwitterUser, TwitterAlreadyLinked,
 from django_oauth_twitter.signals import (twitter_user_associated,
                                           twitter_user_unassociated)
 from django_oauth_twitter.utils import (fail_whale, login_redirect_url,
-                                        TwitterApi, update_qs)
+                                        next_url, TwitterApi, update_qs)
 
 from oauth.oauth import OAuthToken
 
@@ -163,9 +163,9 @@ class OAuthTwitter(object):
         settings.LOGIN_REDIRECT_URLNAME or LOGIN_REDIRECT_URL.
         """
         if success_url is None:
-            success_url = login_redirect_url()
+            success_url = next_url(request)
         else:
-            success_url = reverse(success_url)
+            success_url = str(LazyReverse(success_url))
         # Get a request token.
         twitter = TwitterApi()
         request_token = fail_whale(twitter.getRequestToken)()
@@ -346,10 +346,7 @@ class OAuthTwitter(object):
                           {'error': 'twitter_already_linked',
                            'user': userinfo.screen_name})
             )
-        # Add ?associated=1 to self.association_url
-        association_url = update_qs(success_url,
-                                    {'associated': '1'})
-        return HttpResponseRedirect(association_url)
+        return HttpResponseRedirect(success_url)
 
     def _remove_association(self, request, twitter_id, fail_silently=True):
         """
